#!/usr/bin/env bash
#
# MIT License
#
# (C) Copyright 2024 Hewlett Packard Enterprise Development LP
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
#

set -o errexit
set -o pipefail
set -o xtrace

ROOTDIR="$(dirname "${BASH_SOURCE[0]}")"
source "${ROOTDIR}/lib/version.sh"

# Create scratch space
workdir="$(mktemp -d)"
trap "rm -fr '${workdir}'" EXIT

# Build manifest
cat > "${workdir}/manifest.yaml" << EOF
apiVersion: manifests/v1beta1
metadata:
  name: casmtriage-6698
spec:
  sources:
    charts:
    - name: nexus
      type: repo
      location: https://packages.local/repository/charts
  charts:
  - name: cray-hms-rts
    source: nexus
    version: 4.0.2
    namespace: services
  - name: cray-hms-rts
    releaseName: cray-hms-rts-snmp
    source: nexus
    version: 4.0.2
    namespace: services
    values:
      rtsDoInit: false
      environment:
        cray_hms_rts:
          backend_helper: SNMPSwitch
EOF

# Extract customizations.yaml
kubectl -n loftsman get secret site-init -o jsonpath='{.data.customizations\.yaml}' | base64 -d > "${workdir}/customizations.yaml"

# Extract and update cray-precache-images
kubectl -n loftsman get cm loftsman-platform -o jsonpath='{.data.manifest\.yaml}' | yq r - 'spec.charts(name==cray-precache-images)' > "${workdir}/precache.yaml"
yq w -i "${workdir}/precache.yaml" 'values.cacheImages[+]' "artifactory.algol60.net/csm-docker/stable/hms-redfish-translation-service:1.24.0"
yq w -i "${workdir}/precache.yaml" 'source' "nexus"
yq w -i "${workdir}/manifest.yaml" 'spec.charts[+]' -f "${workdir}/precache.yaml"

# manifestgen
manifestgen -c "${workdir}/customizations.yaml" -i "${workdir}/manifest.yaml" -o "${workdir}/deploy-hotfix.yaml"

# Load artifacts into nexus
${ROOTDIR}/lib/setup-nexus.sh

# Deploy chart
loftsman ship --manifest-path "${workdir}/deploy-hotfix.yaml"

set +x
cat >&2 <<EOF
+ Hotfix installed
${0##*/}: OK
EOF
